[![Discord Server Banner][Discord Server]][Discord Server Invite]
[![Documentation Status][Doc Badge]][Doc Badge Link]
[![PyPI][PypI Badge]][PyPI]


# FerrisWheel
<img src="https://raw.githubusercontent.com/FerrisChat/ferriswheel/v0.0a1.post1/docs/_static/ferriswheel.svg" alt="FerrisWheel Logo" width="300"/>


An async-ready Python wrapper around [FerrisChat](https://ferris.chat)'s API.

## Installation Instructions
Linux:

```sh
$ python3.9 -m pip install -U ferriswheel
```

Python 3.9 can be replaced with your python version.

Windows:
```ps
> py -3 -m pip install -U ferriswheel
```

If you want to install the development version, you can do so with:

```sh
$ python3.9 -m pip install -U git+https://github.com/FerrisChat/ferriswheel
```

Python 3.9 can be replaced with your python version.

Windows:
```ps
> py -3 -m pip install -U git+https://github.com/FerrisChat/ferriswheel
```

If you want to install the packages for performance, you can do so by appending [performance] to the end of the installation command.

For example, if you want to install the speedups, you can do so with:
```sh
$ python3.9 -m pip install -U ferriswheel[performance]
```

Same for windows
```ps
> py -3 -m pip install -U ferriswheel[performance]
```

## Contributing
For contribution information, please see [CONTRIBUTING.md](CONTRIBUTING.md).



[Discord Server]: https://discord.com/api/guilds/874727885640970240/widget.png?style=shield
[Discord Server invite]: https://discord.gg/X4Tyq88MMS
[Doc Badge]: https://readthedocs.org/projects/ferriswheel/badge/?version=latest
[Doc Badge Link]: https://ferriswheel.readthedocs.io/en/latest/?badge=latest
[PyPI Badge]: https://img.shields.io/pypi/v/ferriswheel
[PyPI]: https://pypi.org/project/ferriswheel/
